# Change Log

## 0.1.4

* Add missing dependency
* Add missing instance variable documentation

## 0.1.3

* Code cleanup

## 0.1.2

* Fix `safety` issues
* Fix module name

## 0.1.1

* Add requirements
* Fix `flake8` issues
* Switch back to upstream `pylint`

## 0.1.0

* Initial release
